Learn R Programming

fds (version 1.9)

hmdcountry: Function to read a bundle of data sets from the Human Mortality Database

Description

This function returns a list of relevant demographic data currently available in the HMD, related to a specified country.

Usage

hmdcountry(Country, sex, username, password)

Value

List of objects of class fts.

Arguments

Country

A specified country.

sex

Possible options are "Male", "Female", "Total".

username

Authenticate username.

password

Authenticate password.

Author

Han Lin Shang and Rob J Hyndman

Details

In order to read the data sets, users are required to create their account via the HMD website (https://www.mortality.org/), and obtain a valid username and password.

See Also

read.hmd, hmdstatistic