This function returns a list of all the countries currently available in the HMD, related to a specified data type.
hmdstatistic(sex, type = c("birth count", "death count", "population", "exposure",
"mortality rate", "life expectancy"), username, password)List of objects of class fts.
Possible options are "Male", "Female", "Total".
Type of data.
Authenticate username.
Authenticate password.
Han Lin Shang and Rob J Hyndman
In order to read the data sets, users are required to create their account via the HMD website (https://www.mortality.org/), and obtain a valid username and password.
read.hmd, hmdcountry