Learn R Programming

fds (version 1.9)

read.jpn: Function to read data sets from the Japanese Human Mortality Database

Description

This function allows users to read death rates from the Japanese Human Mortality Database

Usage

read.jpn(region, label = region)

Value

A list of mortality rate objects

Arguments

region

Number index of the prefecture in Japan

label

Name of the prefecture in Japan

Author

Han Lin Shang

Details

In order to use the data sets, users are required to acknowledge the Japanese Human Mortality Database (https://www.ipss.go.jp/p-toukei/JMD/index-en.asp)

References

H. L. Shang and R. J. Hyndman (2017), 'Grouped functional time series forecasting: An application to age-specific mortality rates', Journal of Computational and Graphical Statistics, 26(2), 330-343.

See Also

read.jpn_death

Examples

Run this code
Japan_rate = read.jpn(region = "00", label = "Japan")

Run the code above in your browser using DataLab