This function returns a list of relevant demographic data currently available in the HMD, related to a specified country.
hmdcountry(Country, sex, username, password)List of objects of class fts.
A specified country.
Possible options are "Male", "Female", "Total".
Authenticate username.
Authenticate password.
Han Lin Shang and Rob J Hyndman
In order to read the data sets, users are required to create their account via the HMD website (https://www.mortality.org/), and obtain a valid username and password.
read.hmd, hmdstatistic