powered by
This function allows users to read death rates from the Japanese Human Mortality Database
read.jpn(region, label = region)
A list of mortality rate objects
Number index of the prefecture in Japan
Name of the prefecture in Japan
Han Lin Shang
In order to use the data sets, users are required to acknowledge the Japanese Human Mortality Database (https://www.ipss.go.jp/p-toukei/JMD/index-en.asp)
H. L. Shang and R. J. Hyndman (2017), 'Grouped functional time series forecasting: An application to age-specific mortality rates', Journal of Computational and Graphical Statistics, 26(2), 330-343.
read.jpn_death
Japan_rate = read.jpn(region = "00", label = "Japan")
Run the code above in your browser using DataLab