powered by
This function allows users to read death counts from the Japanese Human Mortality Database
read.jpn_death(region, label = region)
A data frame of death counts, a data frame of population-at-risk
Number index of the prefecture in Japan
Name of the prefecture in Japan
Han Lin Shang
In order to use the data sets, users are required to acknowledge the Japanese Human Mortality Database (https://www.ipss.go.jp/p-toukei/JMD/index-en.asp)
H. L. Shang and R. J. Hyndman (2017), 'Grouped functional time series forecasting: An application to age-specific mortality rates', Journal of Computational and Graphical Statistics, 26(2), 330-343.
read.jpn
Japan_count = read.jpn_death(region = "00", label = "Japan")
Run the code above in your browser using DataLab